%% ColorMeasure : extract the appropriate features for colorfulness assessment
function ColorfulnessMeasure(image, HSVimage, Labimage, fidColor, label)

% Detect main subject components with the aim of k-means objectDetection
[mainSubject] = kmeansSegmentation(image, Labimage, 3);

% Color spaces
[activity, weight, heat, H, S, V, R, G, B] = colorSpaces(image, HSVimage, Labimage);

% Create cells which contain all color components
colorSpace = cell(9,3);
colorSpace{1,1} = activity(mainSubject==1);
colorSpace{1,2} = activity(mainSubject==2);
colorSpace{1,3} = activity(mainSubject==3);
colorSpace{2,1} = weight(mainSubject==1);
colorSpace{2,2} = weight(mainSubject==2);
colorSpace{2,3} = weight(mainSubject==3);
colorSpace{3,1} = heat(mainSubject==1);
colorSpace{3,2} = heat(mainSubject==2);
colorSpace{3,3} = heat(mainSubject==3);
colorSpace{4,1} = H(mainSubject==1);
colorSpace{4,2} = H(mainSubject==2);
colorSpace{4,3} = H(mainSubject==3);
colorSpace{5,1} = S(mainSubject==1);
colorSpace{5,2} = S(mainSubject==2);
colorSpace{5,3} = S(mainSubject==3);
colorSpace{6,1} = V(mainSubject==1);
colorSpace{6,2} = V(mainSubject==2);
colorSpace{6,3} = V(mainSubject==3);
colorSpace{7,1} = im2double(R(mainSubject==1));
colorSpace{7,2} = im2double(R(mainSubject==2));
colorSpace{7,3} = im2double(R(mainSubject==3));
colorSpace{8,1} = im2double(G(mainSubject==1));
colorSpace{8,2} = im2double(G(mainSubject==2));
colorSpace{8,3} = im2double(G(mainSubject==3));
colorSpace{9,1} = im2double(B(mainSubject==1));
colorSpace{9,2} = im2double(B(mainSubject==2));
colorSpace{9,3} = im2double(B(mainSubject==3));

%% Color characterization of the three basic image regions
% Edges end for each category
edgesValue = cell(9,1);
edgesValue{1,1} = 13.1;
edgesValue{2,1} = 8.1;
edgesValue{3,1} = 4.4;
edgesValue{4,1} = 1.1;
edgesValue{5,1} = 1.1;
edgesValue{6,1} = 1.1;
edgesValue{7,1} = 255.1;
edgesValue{8,1} = 255.1;
edgesValue{9,1} = 255.1;

% Xmin end for each category
xminValue = cell(9,1);
xminValue{1,1} = 6;
xminValue{2,1} = -8;
xminValue{3,1} = 0;
xminValue{4,1} = 0;
xminValue{5,1} = 0;
xminValue{6,1} = 0;
xminValue{7,1} = 0;
xminValue{8,1} = 0;
xminValue{9,1} = 0;

% Xmax end for each category
xmaxValue = cell(9,1);
xmaxValue{1,1} = 13;
xmaxValue{2,1} = 8;
xmaxValue{3,1} = 4;
xmaxValue{4,1} = 1;
xmaxValue{5,1} = 1;
xmaxValue{6,1} = 1;
xmaxValue{7,1} = 255;
xmaxValue{8,1} = 255;
xmaxValue{9,1} = 255;

% Initialize the parameters
countFeat = 1;
fprintf(fidColor,'%i ', label);
colorMat = zeros(3,45);
temp = 1;
% Histogram bin contraction
for ii = 1 : 9
    % The number of bins that be computed for each color component/channel (H, S, V)
    Required_Bin_Num = 5;
    
    %fixed width of bins
    xmin = xminValue{ii,1}; % lower bound
    xmax = xmaxValue{ii,1}; % upper bound
    width = (xmax-xmin)/Required_Bin_Num; % bin width
    edges = xmin:width:xmax;
    edges(end) = edgesValue{ii,1};
    
    % Histogram for color region 1
    colorFeature = colorSpace{ii,1};
    [histBins, ~] = histc(colorFeature(:), edges); % variable(:) put all values into a vector(1x(MxN))
    histBins(end) = []; % The last bin is always zero so exclude it.
    histBins = histBins'/(size(colorFeature(:),1)+eps); % Normalization
    colorMat(1,temp:temp+4) = histBins(1,1:5);
    
    % Histogram for color region 2
    colorFeature = colorSpace{ii,2};
    [histBins, ~] = histc(colorFeature(:), edges); % variable(:) put all values into a vector(1x(MxN))
    histBins(end) = []; % The last bin is always zero so exclude it.
    histBins = histBins'/(size(colorFeature(:),1)+eps); % Normalization
    colorMat(2,temp:temp+4) = histBins(1,1:5);
    
    % Histogram for color region 3
    colorFeature = colorSpace{ii,3};
    [histBins, ~] = histc(colorFeature(:), edges); % variable(:) put all values into a vector(1x(MxN))
    histBins(end) = []; % The last bin is always zero so exclude it.
    histBins = histBins'/(size(colorFeature(:),1)+eps); % Normalization
    colorMat(3,temp:temp+4) = histBins(1,1:5);
    
    temp = temp + 5;
end

% Store color "distribution"
colorPath = [pwd '\Colors\'];
colors = {'Black','White','Red','Green','Blue','Brown','Orange','Yellow','Pink','Purple'};
for ii = 1 : 10
    tempColor = dlmread( [colorPath colors{ii} '.txt']);
    D = pdist2(tempColor,colorMat,'euclidean');
    mn = mean(D);
    mn(isnan(mn)) = 0;
    fprintf(fidColor,'%i: %0.6f %i: %0.6f %i: %0.6f ',countFeat,  mn(1), countFeat+1,  mn(2), countFeat+2,  mn(3));
    countFeat = countFeat + 3;
end
%--------------------------------------------------

%% Store the percentage of pixels that contains each chroma region
sizeRegOne = size(mainSubject(mainSubject==1),1)/(size(mainSubject(:),1)+eps);
sizeRegTwo = size(mainSubject(mainSubject==2),1)/(size(mainSubject(:),1)+eps);
sizeRegThree = size(mainSubject(mainSubject==3),1)/(size(mainSubject(:),1)+eps);
fprintf(fidColor,'%i: %0.6f %i: %0.6f %i: %0.6f ', countFeat,  sizeRegOne, countFeat+1,  sizeRegTwo , countFeat+2,  sizeRegThree);
countFeat = countFeat + 3;
%--------------------------------------------------

%% Image Hue, Saturation and Value components
[countFeat] = hsvRuleOfThirds(image, HSVimage, countFeat, fidColor);
%--------------------------------------------------

%% Contrast Measure
% Read ContrastMeasure function from the corresponding path
ContrastPath = [pwd '\ContrastMeasure\'];
cd(ContrastPath)

ContrastScore = ContrastMeasure(image, HSVimage);
% Normalize Contrast score (result of regression)
if ContrastScore > 1.3
    ContrastScore = 1.3;
elseif ContrastScore < -1.3
    ContrastScore = -1.3;
end
ContrastScore = (0.9*(ContrastScore-(-1.3)))/(1.3-(-1.3));
fprintf(fidColor,'%i: %.6f ',countFeat, ContrastScore);
countFeat = countFeat + 1;

% Return to the main directory
cd('..')
%--------------------------------------------------

%% Darkness Measure
% Read DarknessMeasure function from the corresponding path
DarknessPath = [pwd '\DarknessMeasure\'];
cd(DarknessPath)

DarknessScore = DarknessMeasure(image, HSVimage);

% Normalize DarknessScore score (result of regression)
if DarknessScore > 0.3
    DarknessScore = 0.3;
elseif DarknessScore < -0.6
    DarknessScore = -0.6;
end
DarknessScore =  (0.9*(DarknessScore-(-0.6)))/(0.3-(-0.6));

fprintf(fidColor,'%i: %.6f ',countFeat, DarknessScore); 
countFeat = countFeat + 1;

% Return to the main directory
cd('..')
%--------------------------------------------------

%% Color Temperature
saveTemperature(image, countFeat, fidColor)
%--------------------------------------------------

% The end of the vector
fprintf(fidColor,'\n');


% End of the function
end

