%% ContrastMeasure : measure the contrast of image
function [ContrastScore] = ContrastMeasure(image, HSV)
% Write the feature vector in form compatible with libsvm
fid = fopen('EvaluationContrast.txt','w');

% transform RBG color format to HSI
hsi = rgb2hsi(image);
iHSI = hsi(:,:,3);

% Michelson Contrast measure
FMichelson = MichelsonHSI(iHSI);

% RMS Contrast measure
FRMS = RMScontrast(iHSI);

% Histogram analysis for RGB color format
R = image(:,:,1);
G = image(:,:,2);
B = image(:,:,3);

SumR = R(R<=50);
SumG = G(G<=50);
SumB = B(B<=50);

SumR = size(SumR,1);
SumG = size(SumG,1);
SumB = size(SumB,1);

[row, col] = size(R);
ImageArea = row*col;

FR = SumR/ImageArea;
FG = SumG/ImageArea;
FB = SumB/ImageArea;

% Computation of Saturation in HSV color format
S = HSV(:,:,2);

[row, col] = size(S);
ImageArea = row*col;
FS = sum(S(:));
FS = FS / ImageArea;

% Computation of the content of blue
Blue = size(B(B>=150),1);
FCB = Blue / ImageArea;

% Create the features file
fprintf(fid,'1 1: %f 2: %f 3: %f 4: %f 5: %f 6: %f 7: %f\n', FMichelson, FRMS, FR, FG, FB, FS, FCB);

clear FMichelson FRMS FR FG FB FS FCB
% Close the txt file
fclose(fid);

% Evaluation process
% Regression
system('svm-scale -r Contrast_range EvaluationContrast.txt >> EvaluationContrast_scale.txt');
system('svm-predict -b 1 EvaluationContrast_scale.txt Contrast_model output');

ContrastScore = dlmread('output');
ContrastScore = ContrastScore(end);
delete('output', 'EvaluationContrast_scale.txt','EvaluationContrast.txt');

% End of function
end