%% rgb2hsi : convert RGB color format to HSI color format  
function hsi= rgb2hsi(image)

%transform RBG to HSI
im=im2double(image);
r=im(:,:,1);
g=im(:,:,2);
b=im(:,:,3);

%intensity
i=(r+g+b)/3;

%If i=0 then saturation is not defined
if i==0 
    s=zeros(size(image,1),size(image,2));
else 
    s=1-3.*(min(min(r,g),b))./(r+g+b+eps); 
    % eps is a MATLAB defined constant for machine epsilon, to avoid division by 0
end

%if s=0 then hue is not defined
if s==0
    h=zeros(size(image,1),size(image,2));
else
    
    if b>g
		h=acos((0.5*((r-g)+(r-b)))./((sqrt((r-g).^2+(r-b).*(g-b)))+eps));
        h=2*pi-h;
    else
        h=acos((0.5*((r-g)+(r-b)))./((sqrt((r-g).^2+(r-b).*(g-b)))+eps));
        % eps is a MATLAB defined constant for machine epsilon, to avoid division by 0 
    end
end

%normalization of H to [0,1]
h=h/(2*pi);

%concatenates the arrays h,s,i
hsi=cat(3,h,s,i);

% End of the function
end
