%% DarknessMeasure : measure the amount of darkness of image 
function [DarknessScore] = DarknessMeasure(image, HSV)

%Write the feature vector in form compatible to libsvm
fid = fopen('EvaluationDarkness.txt','w');

%% YCbCr format
YCbCr = rgb2ycbcr(image);
Y = YCbCr(:,:,1);
[row, col] = size(Y);

% Initialization
% Computation of the percentage of low luminance (0-50) [Total image]
LumTotal = size(Y(Y<=50),1);

% Computation of the percentage of low luminance (0-50) [upper part image]
LumUpper = size(Y(Y(1:round(row/3),:)<=50),1);

% Computation of the percentage of low luminance (0-50) [middle part image]
LumMiddle = size(Y(Y((round(row/3)+1):(row-round(row/3)),:)<=50),1);

% Computation of the percentage of low luminance (0-50) [lower part image]
LumLower = size(Y(Y(((row-round(row/3))+1):row,:)<=50),1);

% Computation of the content of low luminance (0-50) for each of 9
%blocks in which the image is partitioned.
Luminance= zeros(3,3);
XblockSize = floor(row/3);
YblockSize = floor(col/3);
Xblock = ones(3);
Yblock = ones(3);
Xblock(1) = 1;
Yblock(1) = 1;
Xblock(2) = XblockSize * 1;
Yblock(2) = YblockSize * 1;
Xblock(3) = XblockSize * 2;
Yblock(3) = YblockSize * 2;

parfor xi = 1 : 3
    for yi = 1 : 3
        Luminance(xi,yi) = size(Y(Y((Xblock(xi) : (Xblock(xi)+XblockSize)),(Yblock(yi) : (Yblock(yi)+YblockSize)))<=50),1);
    end
end
% Computation of the percentage
ImSize = row*col;
PatchSize = round(row/3)*col;
BlockSize = XblockSize * YblockSize;

LumUpper = LumUpper/PatchSize;
LumMiddle = LumMiddle / PatchSize;
LumLower = LumLower / PatchSize;
LumTotal = LumTotal / ImSize;
Luminance = Luminance ./ BlockSize;

% Convert the RGB color format into HSV (Hue, Saturation, Value)
% HSV = rgb2hsv(image);%e_change
V = HSV(:,:,3);

% Computation of colorfulness for total image and for its middle
% third
% Image size
[row, col] = size(V);
ImArea = row*col;

% Computation of Colorfulness
ValueTotal = sum(V(:));
ValueTotal = ValueTotal / ImArea;

% Computation of Colorfulness (rule of thirds)
Vroth = V(round(row/3) : round((row*2)/3),round(col/3) : round((col*2)/3));
ValueThird = sum(Vroth(:));
ValueThird = (ValueThird*9) / ImArea;

% Print the train file
fprintf(fid,'-1 1: %f 2: %f 3: %f 4: %f 5: %f 6: %f 7: %f 8: %f 9: %f 10: %f 11: %f 12: %f 13: %f 14: %f 15: %f \n', ...
    LumUpper, LumMiddle, LumLower, LumTotal, Luminance(1,1), Luminance(1,2), Luminance(1,3), ...
    Luminance(2,1), Luminance(2,2), Luminance(2,3), Luminance(3,1), Luminance(3,2), Luminance(3,3), ValueTotal, ValueThird);

%Close the file
fclose(fid);

% Evaluation process
% Regression
system('svm-scale -r Dark_range EvaluationDarkness.txt >> EvaluationDarkness_scale.txt');
system('svm-predict -b 1 EvaluationDarkness_scale.txt Dark_model output');
% DarknessScore = load('output');
DarknessScore = dlmread('output');
DarknessScore = DarknessScore(end);
 
delete('output', 'EvaluationDarkness_scale.txt', 'EvaluationDarkness.txt');

% End of the function
end
