%% colorSpaces : extract image's color spaces
function [activity, weight, heat, H, S, V, L, La, Lb, R, G, B] = colorSpaces(image, HSV, Lab)

% RGB color format
R = image(:,:,1);
G = image(:,:,2);
B = image(:,:,3);

% L channel
L = double(Lab(:,:,1));
% a channel (red-green)
a = double(Lab(:,:,2));
La = a;
% b channel (yellow-blue)
b = double(Lab(:,:,3));
Lb = b;
% Compute the "ab" space
ab = double(Lab(:,:,2:3));
nrows = size(ab,1);
ncols = size(ab,2);
ab = reshape(ab,nrows*ncols,2); % ab(nrows, ncols, 2)

% If the image is in grayscale and a,b == 128 compute the R-G-B
% channels
if size(ab(ab==128),1) > (size(ab(:),1)/3)*2
    % R channel
    L = double(image(:,:,1));
    % G channel
    a = double(image(:,:,2));
    % B channel
    b = double(image(:,:,3));
end

% Chroma
C = sqrt(a.^2+b.^2); % sqrt(a^2+b^2)
% Hue
Hue = atan(b./(a+eps));

% Emotion based color components
activity = -2.1 + 0.06*sqrt((L-50).^2+(a-3).^2+((b-17)/1.4).^2);
weight = -1.8 + 0.04*(100-L) + 0.45*cos(Hue-100);
heat = -0.5 + 0.02*(C.^1.07).*cos(Hue-50);

% Extract image components for each segment (HSV)
H = HSV(:,:,1);
S = HSV(:,:,2);
V = HSV(:,:,3);

% End of the function
end