%% colorTemperature : calculate Correlated Color Temperature (CCT)
%% Reference : C. S. McCamy, Correlated color temperature as an explicit
%% function of chromaticity coordinates, Color Research & Application,
%% vol. 17, no. 2, pp. 142144, 1992.
function [CCT] = colorTemperature(image)
% Convert RGB to XYZ color format
XYZ = rgb2xyz(image);
X = XYZ(:,:,1);
Y = XYZ(:,:,2);
Z = XYZ(:,:,3);

% Calculate the normalized chromaticity values
x = X./(X+Y+Z+eps);
y = Y./(X+Y+Z+eps);

% Compute the CCT value from
n = (x - 0.3320)./(0.1858 - y +eps);
CCT = (449.*n.^3) + (3525.*n.^2) + (6823.3.*n) + 5520.33;

% End of the function
end