%% kmeansSegmentation : if the simple image Segmentation can't find the region of main subject
%% perform k-means image segmentation based on Lab color format 
function [mainSubject] = kmeansSegmentation(image, lab, nColors)

% Classify the colors in "ab" space using k-means clustering
ab = double(lab(:,:,2:3));
nrows = size(ab,1);
ncols = size(ab,2);
ab = reshape(ab,nrows*ncols,2);     % ab(nrows, ncols, 2)

% If the image is in grayscale and a,b == 128 perform kmeans with R-G
if size(ab(ab==128),1) > (size(ab(:),1)/3)*2
    ab = double(image(:,:,2:3));
    nrows = size(ab,1);
    ncols = size(ab,2);
    ab = reshape(ab,nrows*ncols,2); % ab(nrows, ncols, 2)
end

% ** THE NUMBER OF CLUSTERS **
% Number of colors that will be detected.
if nargin == 1
    nColors = 2;
end

%% K- means of matlab (slow version) 
% % Repeat the clustering 5 times to avoid local minima
% iterations = 5;
% [cluster_idx, ~, ~, ~] = kmeans(ab,nColors,'distance','sqEuclidean', ...
%     'emptyaction', 'drop','replicates', iterations);
% 
% %% Label every pixel in the image using the results from kmeans
% pixel_labels = reshape(cluster_idx,nrows,ncols); % a matrix with nColorsID at the position of each cluster
% mainSubject = pixel_labels;

%% K- means of vlfeat (fast version) 
%% Repeat the clustering 5 times to avoid local minima
iterations = 5;
[~, cluster_idx] = vl_kmeans(ab', nColors, 'Initialization', 'plusplus','Algorithm','Elkan' , 'MaxNumIterations',iterations) ;
%% Label every pixel in the image using the results from kmeans
pixel_labels = reshape(cluster_idx',nrows,ncols); % a matrix with nColorsID at the position of each cluster
mainSubject = pixel_labels;


% End of the function
end