%% saveTemperature : estimate CCT histogram for each of the 9 patches of the rule of thirds grid
function saveTemperature(image, countFeat, fid)
    % Color Temperature
    [CCT] = colorTemperature(image);

    % Rule of Thirds
    [row, col, ~] = size(image);
    StX = 1;
    StY = 1;
    EnX = floor(row/3);
    EnY = floor(col/3);
    
    for ii = 1 : 3
        for jj = 1 : 3
            
            % Color temperature estimation
            tempCCT = CCT(StX:EnX,StY:EnY);
            
            % 1000-3000 K
            % The number of bins that be computed for 1000-3000 K of the CCT
            Required_Bin_Num = 8;
            
            xmin = 1000;                            % lower bound
            xmax = 3000;                            % upper bound
            width = (xmax-xmin)/Required_Bin_Num;   % bin width
            edges = xmin:width:xmax;
            edges(end) = 3000.1;
            % Bin contraction
            [Q_CCT, ~] = histc(tempCCT(:), edges);  % variable(:) put all values into a vector(1x(MxN))
            Q_CCT(end) = [];                        % The last bin is always zero so exclude it.
            Q_CCT = Q_CCT/(size(tempCCT(:),1)+eps); % Normalization
            
            fprintf(fid,'%i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, Q_CCT(3), countFeat+1, Q_CCT(5), countFeat+2, Q_CCT(7));
            countFeat = countFeat + 3;
            
            % 4000-5000 K
            % The number of bins that be computed for 4000-5000 K of the CCT
            Required_Bin_Num = 4;
            
            xmin = 4000;                            % lower bound
            xmax = 5000;                            % upper bound
            width = (xmax-xmin)/Required_Bin_Num;   % bin width
            edges = xmin:width:xmax;
            edges(end) = 5000.1;
            % Bin contraction
            [Q_CCT, ~] = histc(tempCCT(:), edges);  % variable(:) put all values into a vector(1x(MxN))
            Q_CCT(end) = [];                        % The last bin is always zero so exclude it.
            Q_CCT = Q_CCT/(size(tempCCT(:),1)+eps); % Normalization
            
            fprintf(fid,'%i: %0.6f ',countFeat, Q_CCT(1));
            countFeat = countFeat + 1;
            
            % 6000-8000 K
            % The number of bins that be computed for 6000-8000 K of the CCT
            Required_Bin_Num = 8;
          
            xmin = 6000;                            % lower bound
            xmax = 8000;                            % upper bound
            width = (xmax-xmin)/Required_Bin_Num;   % bin width
            edges = xmin:width:xmax;
            edges(end) = 8000.1;
            % Bin contraction
            [Q_CCT, ~] = histc(tempCCT(:), edges);  % variable(:) put all values into a vector(1x(MxN))
            Q_CCT(end) = [];                        % The last bin is always zero so exclude it.
            Q_CCT = Q_CCT/(size(tempCCT(:),1)+eps); % Normalization
            
            fprintf(fid,'%i: %0.6f %i: %0.6f ', countFeat, Q_CCT(1), countFeat+1, Q_CCT(5));
            countFeat = countFeat + 2;
            
            % 13000-14000 K
            % The number of bins that be computed for 13000-14000 K of the CCT
            Required_Bin_Num = 4;
         
            xmin = 13000;                           % lower bound
            xmax = 14000;                           % upper bound
            width = (xmax-xmin)/Required_Bin_Num;   % bin width
            edges = xmin:width:xmax;
            edges(end) = 14000.1;
            % Bin contraction
            [Q_CCT, ~] = histc(tempCCT(:), edges);  % variable(:) put all values into a vector(1x(MxN))
            Q_CCT(end) = [];                        % The last bin is always zero so exclude it.
            Q_CCT = Q_CCT/(size(tempCCT(:),1)+eps); % Normalization
            
            fprintf(fid,'%i: %0.6f ', countFeat, Q_CCT(3));
            countFeat = countFeat + 1;
            
            StY = floor((col*jj)/3);
            EnY = floor((col*(jj+1))/3);
        end
        StY = 1;
        EnY = floor(col/3);
        StX = floor((row*ii)/3);
        EnX = floor((row*(ii+1))/3);
    end
    clear CCT tempCCT

% End of the function
end