%% ColorLandscape : estimate color distribution on the 3 patches of the "landscape" grid
function [colorVector] = ColorLandscape(HSV)

[row, ~, ~] = size(HSV);
StY = 1;
EnY = floor(row/3);

% Extract H, S and V components
H = HSV(:,:,1);
S = HSV(:,:,2);
V = HSV(:,:,3);

% Histogram analysis of wavelet on rule of thirds grid
% The number of bins that be computed for each color component/channel (H, S, V)
Required_Bin_Num = 5;

xmin = 0;                               % lower bound
xmax = 1;                               % upper bound
width = (xmax-xmin)/Required_Bin_Num;   % bin width
edges = xmin:width:xmax;
edges(end) = 1.1;


colorMat = zeros(3,15);
temp = 1;
%% Image Hue, Saturation and Value
for i = 1 : 3
    tempH = H(StY:EnY,:);
    
    % Histogram for color region 3
    [histBins, ~] = histc(tempH(:), edges);         % variable(:) put all values into a vector(1x(MxN))
    histBins(end) = [];                             % The last bin is always zero so exclude it.
    histBins = histBins'/(size(tempH(:),1)+eps);    % Normalization
    colorMat(1,temp:temp+4) = histBins(1,1:5);
    
    tempS = S(StY:EnY,:);
    
    % Histogram for color region 3
    [histBins, ~] = histc(tempS(:), edges);         % variable(:) put all values into a vector(1x(MxN))
    histBins(end) = [];                             % The last bin is always zero so exclude it.
    histBins = histBins'/(size(tempS(:),1)+eps);    % Normalization
    colorMat(2,temp:temp+4) = histBins(1,1:5);
       
    tempV = V(StY:EnY,:);
    
    % Histogram for color region 3
    [histBins, ~] = histc(tempV(:), edges);         % variable(:) put all values into a vector(1x(MxN))
    histBins(end) = [];                             % The last bin is always zero so exclude it.
    histBins = histBins'/(size(tempV(:),1)+eps);    % Normalization
    colorMat(3,temp:temp+4) = histBins(1,1:5);
    
    temp = temp + 5;
    StY = floor((row*i)/3);
    EnY = floor((row*(i+1))/3);
end

colorVector = [colorMat(1,:) colorMat(2,:) colorMat(3,:)];

% End of the function
end
