%% GridCenter : extract the appropriate features for "fill the frame" composition assessment
function [CenterFeatures] = GridCenter( image, boxes, numOfWindows, fidCenter)

% Initialize the grid for "fill the frame" composition
[row, col, ~] = size(image);
gridXmin = round((col/2)-(col/3));
gridXmax = ceil((col/2)+(col/3));
gridYmin = round((row/2)-(row/3));
gridYmax = ceil((row/2)+(row/3));
gridCenterX = round(col/2);
gridCenterY = round(row/2);

% Save boxes properties
xmin = boxes(:,1);
ymin = boxes(:,2);
xmax = boxes(:,3);
ymax = boxes(:,4);

% The center of the boxes
centerX = xmin+(abs(xmax-xmin)/2);
centerY = ymin+(abs(ymax-ymin)/2);

% The euclidean distance between the center of boxes and the center of image
eclDistance(1,:) = sqrt((gridCenterX-centerX).^2+(gridCenterY-centerY).^2)./(col+eps);

% The angle between the center of boxes and x axis(the center of image is considered as the center of axis)
cosa(1,:) = (gridCenterX-centerX)./(sqrt((gridCenterX-centerX).^2+(gridCenterY-centerY).^2)+eps);

% Width of boxes lines
widthX(1,:) = abs(xmax-xmin)/col;

% Height of boxes lines
heightY(1,:) = abs(ymax-ymin)/row;

% The spacial overlap between the center grid and object's boxes
intrsArea = zeros(1,8);
parfor i = 1 : numOfWindows
    
    % Initialize the corners of the intersection rectangles
    tempYmin = 0;
    tempYmax = 0;
    tempXmin = 0;
    tempXmax = 0;
    
    if ymax(i) >= gridYmin && ymax(i) <= gridYmax
        tempYmax =  ymax(i);
        if ymin(i) <= gridYmin
            tempYmin = gridYmin;
        end
    end
    
    if ymin(i) >= gridYmin && ymin(i) <= gridYmax
        tempYmin = ymin(i);
        if ymax(i) >= gridYmax
            tempYmax = gridYmax;
        end
    end
    
    if xmax(i) >= gridXmin && xmax(i) <= gridXmax
        tempXmax =  xmax(i);
        if xmin(i) <= gridXmin
            tempXmin = gridXmin;
        end
    end
    
    if xmin(i) >= gridXmin && xmin(i) <= gridXmax
        tempXmin = xmin(i);
        if xmax(i) >= gridXmax
            tempXmax = gridXmax;
        end
    end
    
    if ymin(i) <= gridYmin && ymax(i) >= gridYmax
        tempYmin = gridYmin;
        tempYmax = gridYmax;
    end
    
    if xmin(i) <= gridXmin && xmax(i) >= gridXmax
        tempXmin = gridXmin;
        tempXmax = gridXmax;
    end
    
    intrsArea(1,i) = (abs(tempXmax-tempXmin)*abs(tempYmax-tempYmin))/(abs(gridXmax-gridXmin)*abs(gridYmax-gridYmin));
    
end

% Wavelet analysis of a centered patch of the image
cropImage = image(round((row/2)-(row/3)):ceil((row/2)+(row/3)),round((col/2)-(col/3)):ceil((col/2)+(col/3)));
waveletVector = WaveletAnalysis( cropImage);

% Center feature vector
CenterFeatures = [eclDistance cosa intrsArea widthX heightY waveletVector];

% Print the feature vector
temp = repmat('%0.6f ',1,85);
fprintf(fidCenter,[temp(1:end-1) '\n'],CenterFeatures);

% End of the function
end

