%% GridLandscape : extract the appropriate features for "landscape" composition rule assessment
function [LandscapeFeatures] = GridLandscape( image, HSVimage, boxes, numOfWindows, fidLandscape)

% Initialize the grid for "landscape" composition
[row, col, ~] = size(image);
gridXmean = round(col/2);
gridYmin = round(row/3);
gridYmax = round(row/3)*2;

% Save boxes properties
xmin = boxes(:,1);
xmax = boxes(:,3);
ymin = boxes(:,2);
ymax = boxes(:,4);

% Width of boxes lines
widthX(1,:) = abs(xmax-xmin)/col;
% Height of boxes lines
heightY(1,:) = abs(ymax-ymin)/row;

% Upper part of image
upXmin = 1;
upXmax = col;
upYmin = 1;
upYmax = gridYmin;
upDistanceFeatures  = distanceMeasures( gridXmean, gridYmin - round(gridYmin/2) , boxes, numOfWindows)./(col+eps);
upAreaFeatures = intersectionArea( upXmin, upXmax, upYmin, upYmax , boxes, numOfWindows);

% Middle part of image
midXmin = 1;
midXmax = col;
midYmin = gridYmin;
midYmax = gridYmax;
midDistanceFeatures  = distanceMeasures( gridXmean, gridYmin + round(gridYmin/2) , boxes, numOfWindows)./(col+eps);
midAreaFeatures = intersectionArea( midXmin, midXmax, midYmin, midYmax , boxes, numOfWindows);

% Bottom part of image
botXmin = 1;
botXmax = col;
botYmin = gridYmax;
botYmax = row;
botDistanceFeatures  = distanceMeasures( gridXmean, gridYmax + round(gridYmin/2) , boxes, numOfWindows)./(col+eps);
botAreaFeatures = intersectionArea( botXmin, botXmax, botYmin, botYmax , boxes, numOfWindows);

% Color features vector
colorVector = ColorLandscape(HSVimage);

% Landscape features vector
LandscapeFeatures = [widthX heightY upDistanceFeatures midDistanceFeatures botDistanceFeatures upAreaFeatures midAreaFeatures botAreaFeatures colorVector];

% Print the feature vector
temp=repmat('%0.6f ',1,133);
fprintf(fidLandscape,[temp(1:end-1) '\n'],LandscapeFeatures);

% End of the function
end

