%% GridRuleOfThirds : extract the appropriate features for "rule of third" composition rule assessment
function [RuleOfThirdsFeatures] = GridRuleOfThirds( image, boxes, numOfWindows, fidRuleOfThirds)

% Initialize the grid for "rule of thirds" composition
[row, col, ~] = size(image);
gridXmin = round(col/3);
gridXmax = round(col/3)*2;
gridYmin = round(row/3);
gridYmax = round(row/3)*2;

% Up-left intersection
ulXmin = round(gridXmin - gridXmin/3);
ulXmax = round(gridXmin + gridXmin/3);
ulYmin = round(gridYmin - gridYmin/3);
ulYmax = round(gridYmin + gridYmin/3);

% Up-right intersection
urXmin = round(gridXmax - gridXmin/3);
urXmax = round(gridXmax + gridXmin/3);
urYmin = round(gridYmin - gridYmin/3);
urYmax = round(gridYmin + gridYmin/3);

% Bottom-left intersection
blXmin = round(gridXmin - gridXmin/3);
blXmax = round(gridXmin + gridXmin/3);
blYmin = round(gridYmax - gridYmin/3);
blYmax = round(gridYmax + gridYmin/3);

% Bottom-right intersection
brXmin = round(gridXmax - gridXmin/3);
brXmax = round(gridXmax + gridXmin/3);
brYmin = round(gridYmax - gridYmin/3);
brYmax = round(gridYmax + gridYmin/3);

% Distance measures (euclidean distance and angle)
ulDistanceFeatures  = distanceMeasures( gridXmin, gridYmin , boxes, numOfWindows)./(col+eps);
urDistanceFeatures  = distanceMeasures( gridXmax, gridYmin , boxes, numOfWindows)./(col+eps);
blDistanceFeatures  = distanceMeasures( gridXmin, gridYmax , boxes, numOfWindows)./(col+eps);
brDistanceFeatures  = distanceMeasures( gridXmax, gridYmax , boxes, numOfWindows)./(col+eps);

% The spacial overlap between rule of thirds grids and boxes
ulAreaFeatures = intersectionArea( ulXmin, ulXmax, ulYmin, ulYmax , boxes, numOfWindows);
urAreaFeatures = intersectionArea( urXmin, urXmax, urYmin, urYmax , boxes, numOfWindows);
blAreaFeatures = intersectionArea( blXmin, blXmax, blYmin, blYmax , boxes, numOfWindows);
brAreaFeatures = intersectionArea( brXmin, brXmax, brYmin, brYmax , boxes, numOfWindows);

% Rule of third feature vector
RuleOfThirdsFeatures = [ulDistanceFeatures urDistanceFeatures blDistanceFeatures brDistanceFeatures ulAreaFeatures urAreaFeatures blAreaFeatures brAreaFeatures];

% Print the feature vector
temp = repmat('%0.6f ',1,96);
fprintf(fidRuleOfThirds,[temp(1:end-1) '\n'],RuleOfThirdsFeatures);

% End of the function
end

