%%  WaveletAnalysis : extract the appropriate features of wavelet Haar transform
function [waveletVector] = WaveletAnalysis( image)
% Convert RGB images to grayscale
% rgb -> grayscale
if(size(image,3)~=1)
    image = rgb2gray(image);
end
% Enhance contrast
image = adapthisteq(image);

%% Wavelet transform
hVector = zeros(3,5);
vVector = zeros(3,5);
d1Vector = zeros(3,5);

% The number of the scales of the haar transformation
NumScales = 3;
% Haar transformation
[C, S] = wavedec2(image,NumScales,'haar');
Emap = cell(NumScales);

for ii = 1 : NumScales
    [horizontal, vertical, diagonal] = detcoef2('all',C,S,ii);
    % Compute the edge map in each scale
    Emap(ii) = {sqrt(horizontal.^2 + vertical.^2 + diagonal.^2)}; 
    Edges = Emap{ii};
    % Image size
    [row, col] =  size(Edges);
      
    %%%%%% Horizontal %%%%%%%
    % Edges
    imH1 = Edges;
    imH2 = Edges;
    imH1(round(row/2):end,:) = 0 ;
    imH2(1:round(row/2),:) = 0 ;

    imEdgesH1 = imH1(imH1~=0);
    imEdgesH2 = imH2(imH2~=0);
    
    % mean
    mnH1 = nanmean(imEdgesH1);
    mnH2 = nanmean(imEdgesH2);
    % standard deviation
    stdH1 = nanstd(imEdgesH1);
    stdH2 = nanstd(imEdgesH2);
    % KullbackLeibler divergence
    Dkl1 =(((mnH1-mnH2).^2)/(2*stdH2.^2));
    Dkl2 = 0.5*((stdH1.^2/stdH2.^2)-1-log(stdH1.^2/stdH2.^2));
    Dkl = Dkl1 + Dkl2;
    
    if isnan(mnH1)
        mnH1 = 0;
    end
    if isnan(mnH2)
        mnH2 = 0;
    end
    if isnan(stdH1)
        stdH1 = 0;
    end
    if isnan(stdH2)
        stdH2 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
    hVector(ii,:) = [mnH1 stdH1 mnH2 stdH2 Dkl];
   
    %%%%%% Vertical %%%%%%
    % Edges
    imV1 = Edges;
    imV2 = Edges;
    imV1(:,round(col/2):end) = 0 ;
    imV2(:,1:round(col/2)) = 0 ;
   
    imEdgesV1 = imV1(imV1~=0);
    imEdgesV2 = imV2(imV2~=0);
    % mean
    mnV1 = nanmean(imEdgesV1);
    mnV2 = nanmean(imEdgesV2);
    % standard deviation
    stdV1 = nanstd(imEdgesV1);
    stdV2 = nanstd(imEdgesV2);
    % KullbackLeibler divergence
    Dkl1 =(((mnV1-mnV2).^2)/(2*stdV2.^2));
    Dkl2 = 0.5*((stdV1.^2/stdV2.^2)-1-log(stdV1.^2/stdV2.^2));
    Dkl = Dkl1 + Dkl2;
    
    if isnan(mnV1)
        mnV1 = 0;
    end
    if isnan(mnV2)
        mnV2 = 0;
    end
    if isnan(stdV1)
        stdV1 = 0;
    end
    if isnan(stdV2)
        stdV2 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
	vVector(ii,:) = [mnV1 stdV1 mnV2 stdV2 Dkl];
    
    %%%%% Diagonal 1 %%%%%%
    % Edges
    if col < row
        Edges = imresize(Edges,[col col]);
    else
        Edges = imresize(Edges,[col col]);
    end
    imD11 = im2double(Edges);
    imD12 = im2double(Edges);
    
    maskD = triu(ones(col,col),0);
    imD11 = imD11 .* maskD; 
    
    maskD = tril(ones(col,col),-1);
    imD12 =  imD12 .* maskD;

    imEdgesD11 = imD11(imD11~=0);
    imEdgesD12 = imD12(imD12~=0);
    % mean
    mnD11 = nanmean(imEdgesD11);
    mnD12 = nanmean(imEdgesD12);
    % standard deviation
    stdD11 = nanstd(imEdgesD11);
    stdD12 = nanstd(imEdgesD12);
    % KullbackLeibler divergence
    Dkl1 =(((mnD11-mnD12).^2)/(2*stdD12.^2));
    Dkl2 = 0.5*((stdD11.^2/stdD12.^2)-1-log(stdD11.^2/stdD12.^2));
    Dkl = Dkl1 + Dkl2;
    
    if isnan(mnD11)
        mnD11 = 0;
    end
    if isnan(mnD12)
        mnD12 = 0;
    end
    if isnan(stdD11)
        stdD11 = 0;
    end
    if isnan(stdD12)
        stdD12 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
     d1Vector(ii,:) = [mnD11 stdD11 mnD12 stdD12 Dkl];
    
    % Clear image features
    clear EdgeMaxX Edges EdgeMaxY EdgeMinX EdgeMinY
    
end
clear horizontal C S vertical diagonal Emap EdgeMap

waveletVector = [ hVector(1,:) vVector(1,:) d1Vector(1,:) hVector(2,:) vVector(2,:) d1Vector(2,:) hVector(3,:) vVector(3,:) d1Vector(3,:)];

%End of the function
end

