%% ConcatenateVectors : concatenate individual feature vectors in one element vector                                          %%
%% input variables                                                                                                             %%                  
%% outputFile : the name of the .txt file where the final element vector will be stored (e.g. outputFile='featureVector.txt') %%
%% label      : the label of feature vectors (1 or -1), in order to be compatible with LIBSVM                                 %%
%% mode       : if mode = 1 it concatenates each individual feature vector in one final element vector                        %%
%%              if mode = 0 it concatenates the composition feature vectors (Center, Rule of thirds, Landscape)               %%
%%              in one final composition element vector.                                                                      %%
%% -------------------------------------------------------------------------------------------------------------------------- %%
function ConcatenateVectors( outputFile, label , mode)
if (mode == 1)
    % Simplicity
    fileID = fopen('Results\Simplicity.txt','r');
    temp = repmat('%q %f ',1,179);
    temp = ['%f ' temp];
    fSimple = textscan(fileID,temp,'Delimiter',' ');
    szSimple = size(fSimple,2);
    fclose(fileID);
    
    % Colorfulness
    fileID = fopen('Results\Colorfulness.txt','r');
    temp = repmat('%q %f ',1,125);
    temp = ['%f ' temp];
    fColor = textscan(fileID,temp,'Delimiter',' ');
    szColor = size(fColor,2);
    fclose(fileID);
    
    % Sharpness
    fileID = fopen('Results\Sharpness.txt','r');
    temp = repmat('%q %f ',1,635);
    temp = ['%f ' temp];
    fBlur = textscan(fileID,temp,'Delimiter',' ');
    szBlur = size(fBlur,2);
    fclose(fileID);
    
    % Pattern
    fileID = fopen('Results\Pattern.txt','r');
    temp = repmat('%q %f ',1,70);
    temp = ['%f ' temp];
    fPattern = textscan(fileID,temp,'Delimiter',' ');
    szPattern = size(fPattern,2);
    fclose(fileID);
    
    % Center
    fileID = fopen('Results\Center.txt','r');
    temp = repmat('%q %f ',1,85);
    temp = ['%f ' temp];
    fCenter = textscan(fileID,temp,'Delimiter',' ');
    szCenter = size(fCenter,2);
    fclose(fileID);
    
    % Rule Of Thirds
    fileID = fopen('Results\RuleOfThirds.txt','r');
    temp = repmat('%q %f ',1,96);
    temp = ['%f ' temp];
    fRuleOfThirds = textscan(fileID,temp,'Delimiter',' ');
    szRuleOfThirds = size(fRuleOfThirds,2);
    fclose(fileID);
    
    % Landscape
    fileID = fopen('Results\Landscape.txt','r');
    temp = repmat('%q %f ',1,133);
    temp = ['%f ' temp];
    fLandscape = textscan(fileID,temp,'Delimiter',' ');
    szLandscape = size(fLandscape,2);
    fclose(fileID);
        
    % Print the results
    fid = fopen(outputFile,'w');
    numOfImages = size(fCenter{1,1},1);
    for j = 1 : numOfImages
        fprintf(fid,'%i ', label);
        tempSign = 1;
        for i = 3 : 2 : szSimple
            vecSimple = fSimple{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign,vecSimple(j,1) );
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szColor
            vecColor = fColor{1,i};
            fprintf(fid,' %i: %0.6f ',tempSign,  vecColor(j,1));
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szBlur
            vecBlur = fBlur{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecBlur(j,1));
            tempSign = tempSign+ 1;
        end
        for i = 3 : 2 : szPattern
            vecPattern = fPattern{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecPattern(j,1));
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szCenter
            vecCenter = fCenter{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecCenter(j,1));
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szRuleOfThirds
            vecRuleOfThirds = fRuleOfThirds{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecRuleOfThirds(j,1));
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szLandscape
            vecLandscape = fLandscape{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecLandscape(j,1));
            tempSign= tempSign + 1;
        end
        
        fprintf(fid,'\n');
    end
    fclose(fid);
else
    % Center
    fileID = fopen('Results\Center.txt','r');
    temp = repmat('%q %f ',1,85);
    temp = ['%f ' temp];
    fCenter = textscan(fileID,temp,'Delimiter',' ');
    szCenter = size(fCenter,2);
    fclose(fileID);
    
    % Rule Of Thirds
    fileID = fopen('Results\RuleOfThirds.txt','r');
    temp = repmat('%q %f ',1,96);
    temp = ['%f ' temp];
    fRuleOfThirds = textscan(fileID,temp,'Delimiter',' ');
    szRuleOfThirds = size(fRuleOfThirds,2);
    fclose(fileID);
    
    % Landscape
    fileID = fopen('Results\Landscape.txt','r');
    temp = repmat('%q %f ',1,133);
    temp = ['%f ' temp];
    fLandscape = textscan(fileID,temp,'Delimiter',' ');
    szLandscape = size(fLandscape,2);
    fclose(fileID);
    
    % Print the results
    
    fid = fopen(outputFile,'w');
    numOfImages = size(fCenter{1,1},1);
    for j = 1 : numOfImages
        fprintf(fid,'%i ', label);
        tempSign = 1;
        for i = 3 : 2 : szCenter
            vecCenter = fCenter{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecCenter(j,1));
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szRuleOfThirds
            vecRuleOfThirds = fRuleOfThirds{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecRuleOfThirds(j,1));
            tempSign = tempSign + 1;
        end
        for i = 3 : 2 : szLandscape
            vecLandscape = fLandscape{1,i};
            fprintf(fid,'%i: %0.6f ',tempSign, vecLandscape(j,1));
            tempSign= tempSign + 1;
        end
        
        fprintf(fid,'\n');
    end
    fclose(fid);
end
% End of the function
end

