%% PatternMeasure : extract the appropriate features for pattern assessment
function PatternMeasure(image, fidPattern, label)

% Print the label
fprintf(fidPattern,'%i ', label);

image = imresize(image, [512 512]);
image = adapthisteq(image);

[row, col] = size(image);

%%%%%% Horizontal %%%%%%%
imH1 = image;
imH2 = image;
imH1(round(row/2):end,:) = 0 ;
imH2(1:round(row/2),:) = 0 ;

% Perform Surf matching
points1 = detectSURFFeatures(imH1,'MetricThreshold',50);
points2 = detectSURFFeatures(imH2,'MetricThreshold',50);
[f1, ~] = extractFeatures(imH1, points1);
[f2, ~] = extractFeatures(imH2, points2);
indexPairs = matchFeatures(f1, f2) ;
fprintf(fidPattern,'1: %i ',size(unique(indexPairs(:,2)),1));

clear Ia Ib fa da fb db matches scores
%--------------------------------------------------

%%%%%% Vertical %%%%%%
imV1 = image;
imV2 = image;
imV1(:,round(col/2):end) = 0 ;
imV2(:,1:round(col/2)) = 0 ;

% Perform Surf matching
points1 = detectSURFFeatures(imV1,'MetricThreshold',50);
points2 = detectSURFFeatures(imV2,'MetricThreshold',50);
[f1, ~] = extractFeatures(imV1, points1);
[f2, ~] = extractFeatures(imV2, points2);
indexPairs = matchFeatures(f1, f2) ;
fprintf(fidPattern,'2: %i ',size(unique(indexPairs(:,2)),1));

clear Ia Ib fa da fb db matches scores
%--------------------------------------------------

%%%%% Diagonal 1 %%%%%%
image = imresize(image,[col col]);
imD1 = im2double(image);
imD2 = im2double(image);

maskD = triu(ones(col,col),0);
imD1 = imD1 .* maskD; 

maskD = tril(ones(col,col),-1);
imD2 =  imD2 .* maskD;

% Perform Surf matching
points1 = detectSURFFeatures(imD1,'MetricThreshold',50);
points2 = detectSURFFeatures(imD2,'MetricThreshold',50);
[f1, ~] = extractFeatures(imD1, points1);
[f2, ~] = extractFeatures(imD2, points2);
indexPairs = matchFeatures(f1, f2) ;
fprintf(fidPattern,'3: %i ',size(unique(indexPairs(:,2)),1));

clear Ia Ib fa da fb db matches scores
%--------------------------------------------------

%%%%% Diagonal 2 %%%%%%

image = imresize(image,[col col]);
imD21 = im2double(image);
imD22 = im2double(image);

maskD = triu(ones(col,col),0);
imD21 = imD21 .* fliplr(maskD); 

maskD = tril(ones(col,col),-1);
imD22 =  imD22 .* fliplr(maskD);

% Perform Surf matching
points1 = detectSURFFeatures(imD21,'MetricThreshold',50);
points2 = detectSURFFeatures(imD22,'MetricThreshold',50);
[f1, ~] = extractFeatures(imD21, points1);
[f2, ~] = extractFeatures(imD22, points2);
indexPairs = matchFeatures(f1, f2) ;
fprintf(fidPattern,'4: %i ',size(unique(indexPairs(:,2)),1));

clear Ia Ib fa da fb db matches scores
%--------------------------------------------------

%% Wavelet transform for pattern recognition 
countFeat = 5;
PatternWavelet( image, fidPattern, countFeat);
%--------------------------------------------------

fprintf(fidPattern,'\n');

%End of the function
end