%% PatternWavelet : extract the appropriate features for 
%% pattern and symmetry detection performing wavelet Haar transform
function PatternWavelet( image, fidPattern, countFeat)
% The number of the scales of the Haar transformation
NumScales = 3;
% Haar transformation
[C, S] = wavedec2(image,NumScales,'haar');
Emap = cell(NumScales);

for ii = 1 : NumScales
    [horizontal, vertical, diagonal] = detcoef2('all',C,S,ii);
    % Compute the edge map in each scale
    Emap(ii) = {sqrt(horizontal.^2 + vertical.^2 + diagonal.^2)};
    
    Edges = Emap{ii};
    % Image size
    [row, col] =  size(Edges);
    
    %%%%%% Whole image %%%%%%%
    imEdges = Edges(Edges~=0);
    % mean
    mn = nanmean(imEdges);
    % standard deviation
    std = nanstd(imEdges);
    
    if isnan(mn)
        mn = 0;
    elseif isnan(std)
        std = 0;
    end
    % Print the corresponding values
    fprintf(fidPattern,'%i: %0.6f %i: %0.6f ', countFeat, mn, countFeat+1, std);
    countFeat = countFeat + 2;
    %--------------------------------------------------

    %%%%%% Horizontal %%%%%%%
    % Edges
    imH1 = Edges;
    imH2 = Edges;
    imH1(round(row/2):end,:) = 0 ;
    imH2(1:round(row/2),:) = 0 ;
  
    imEdgesH1 = imH1(imH1~=0);
    imEdgesH2 = imH2(imH2~=0);
    
    % mean
    mnH1 = nanmean(imEdgesH1);
    mnH2 = nanmean(imEdgesH2);
    % standard deviation
    stdH1 = nanstd(imEdgesH1);
    stdH2 = nanstd(imEdgesH2);
    % KullbackLeibler divergence
    Dkl1 =(((mnH1-mnH2).^2)/(2*stdH2.^2));
    Dkl2 = 0.5*((stdH1.^2/stdH2.^2)-1-log(stdH1.^2/stdH2.^2));
    Dkl = Dkl1 + Dkl2;
    
    if isnan(mnH1)
        mnH1 = 0;
    end
    if isnan(mnH2)
        mnH2 = 0;
    end
    if isnan(stdH1)
        stdH1 = 0;
    end
    if isnan(stdH2)
        stdH2 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
    fprintf(fidPattern,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, mnH1, countFeat+1, stdH1, countFeat+2, mnH2, countFeat+3, stdH2, countFeat+4, Dkl);
    countFeat = countFeat + 5;
    %--------------------------------------------------
    
    %%%%%% Vertical %%%%%%
    % Edges
    imV1 = Edges;
    imV2 = Edges;
    imV1(:,round(col/2):end) = 0 ;
    imV2(:,1:round(col/2)) = 0 ;

    imEdgesV1 = imV1(imV1~=0);
    imEdgesV2 = imV2(imV2~=0);
  
    % mean
    mnV1 = nanmean(imEdgesV1);
    mnV2 = nanmean(imEdgesV2);
    % standard deviation
    stdV1 = nanstd(imEdgesV1);
    stdV2 = nanstd(imEdgesV2);
    % KullbackLeibler divergence
    Dkl1 =(((mnV1-mnV2).^2)/(2*stdV2.^2));
    Dkl2 = 0.5*((stdV1.^2/stdV2.^2)-1-log(stdV1.^2/stdV2.^2));
    Dkl = Dkl1 + Dkl2;
        
    if isnan(mnV1)
        mnV1 = 0;
    end
    if isnan(mnV2)
        mnV2 = 0;
    end
    if isnan(stdV1)
        stdV1 = 0;
    end
    if isnan(stdV2)
        stdV2 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
    fprintf(fidPattern,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, mnV1, countFeat+1, stdV1, countFeat+2, mnV2, countFeat+3, stdV2, countFeat+4, Dkl);
    countFeat = countFeat + 5;
    %--------------------------------------------------
     
    %%%%% Diagonal 1 %%%%%%
    % Edges
    if col < row
        Edges = imresize(Edges,[col col]);
    else
        Edges = imresize(Edges,[col col]);
    end
    imD11 = im2double(Edges);
    imD12 = im2double(Edges);
    
    maskD = triu(ones(col,col),0);
    imD11 = imD11 .* maskD; 
    
    maskD = tril(ones(col,col),-1);
    imD12 =  imD12 .* maskD; 
 
    imEdgesD11 = imD11(imD11~=0);
    imEdgesD12 = imD12(imD12~=0);
   
    % mean
    mnD11 = nanmean(imEdgesD11);
    mnD12 = nanmean(imEdgesD12);
    % standard deviation
    stdD11 = nanstd(imEdgesD11);
    stdD12 = nanstd(imEdgesD12);
    % KullbackLeibler divergence
    Dkl1 =(((mnD11-mnD12).^2)/(2*stdD12.^2));
    Dkl2 = 0.5*((stdD11.^2/stdD12.^2)-1-log(stdD11.^2/stdD12.^2));
    Dkl = Dkl1 + Dkl2;
    
    if isnan(mnD11)
        mnD11 = 0;
    end
    if isnan(mnD12)
        mnD12 = 0;
    end
    if isnan(stdD11)
        stdD11 = 0;
    end
    if isnan(stdD12)
        stdD12 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
    fprintf(fidPattern,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, mnD11, countFeat+1, stdD11, countFeat+2, mnD12, countFeat+3, stdD12, countFeat+4, Dkl);
    countFeat = countFeat + 5;
    %--------------------------------------------------

    %%%%% Diagonal 2 %%%%%%
    % Edges
    imD21 = im2double(Edges);
    imD22 = im2double(Edges);
    
    maskD = triu(ones(col,col),0);
    imD21 = imD21 .* fliplr(maskD);
    
    maskD = tril(ones(col,col),-1);
    imD22 =  imD22 .* fliplr(maskD); 
    
    imEdgesD21 = imD21(imD21~=0);
    imEdgesD22 = imD22(imD22~=0);
    % mean
    mnD21 = nanmean(imEdgesD21);
    mnD22 = nanmean(imEdgesD22);
    % standard deviation
    stdD21 = nanstd(imEdgesD21);
    stdD22 = nanstd(imEdgesD22);
    % KullbackLeibler divergence
    Dkl1 =(((mnD21-mnD22).^2)/(2*stdD22.^2));
    Dkl2 = 0.5*((stdD21.^2/stdD22.^2)-1-log(stdD21.^2/stdD22.^2));
    Dkl = Dkl1 + Dkl2;
   
    if isnan(mnD21)
        mnD21 = 0;
    end
    if isnan(mnD22)
        mnD22 = 0;
    end
    if isnan(stdD21)
        stdD21 = 0;
    end
    if isnan(stdD22)
        stdD22 = 0 ;
    end
    if isnan(Dkl)
        Dkl = 0 ;
    end
    % Print the corresponding values
    fprintf(fidPattern,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, mnD21, countFeat+1, stdD21, countFeat+2, mnD22, countFeat+3, stdD22, countFeat+4, Dkl);
    countFeat = countFeat + 5;
    %--------------------------------------------------
  
    % Clear image features
    clear EdgeMaxX Edges EdgeMaxY EdgeMinX EdgeMinY
    
end
clear horizontal C S vertical diagonal Emap EdgeMap

%End of the function
end

