%% SharpnessMeasure : extract the appropriate features for sharpness assessment
%% Image Blur Detection based on  E.Mavridaki and V.Mezaris, No-reference blur assessment in
%% natural images using Fourier transform and spatial pyramids, in Proc. of Int. Conf. on Image Processing (ICIP). IEEE, 2014
function SharpnessMeasure(image, fidBlur, label)


% Image segmentation according to the rule of thirds
[ImX, ImY] = size(image);

SectOne =  image(1:floor(ImX/3),1:floor(ImY/3));
SectTwo =  image(1:floor(ImX/3),floor(ImY/3):floor(ImY*2/3));
SectThree =  image(1:floor(ImX/3),floor(ImY*2/3):ImY);

SectFour = image(floor(ImX/3):floor(ImX*2/3),1:floor(ImY/3));
SectFive = image(floor(ImX/3):floor(ImX*2/3),floor(ImY/3):floor(ImY*2/3));
SectSix = image(floor(ImX/3):floor(ImX*2/3),floor(ImY*2/3):ImY);

SectSeven = image(floor(ImX*2/3):ImX,1:floor(ImY/3));
SectEight = image(floor(ImX*2/3):ImX,floor(ImY/3):floor(ImY*2/3));
SectNine = image(floor(ImX*2/3):ImX,floor(ImY*2/3):ImY);
%--------------------------------------------------

% Fourier transform computation

FftSectOne = fft2(SectOne);
FftSectTwo = fft2(SectTwo);
FftSectThree = fft2(SectThree);
FftSectFour = fft2(SectFour);
FftSectFive = fft2(SectFive);
FftSectSix = fft2(SectSix);
FftSectSeven = fft2(SectSeven);
FftSectEight = fft2(SectEight);
FftSectNine = fft2(SectNine);
%--------------------------------------------------

% Power spectrum computation

PowerSec{1,1} = 10 *  log((abs(FftSectOne).^2)+1);
PowerSec{1,2} = 10 *  log((abs(FftSectTwo).^2)+1);
PowerSec{1,3} = 10 *  log((abs(FftSectThree).^2)+1);
PowerSec{1,4} = 10 *  log((abs(FftSectFour).^2)+1);
PowerSec{1,5} = 10 *  log((abs(FftSectFive).^2)+1);
PowerSec{1,6} = 10 *  log((abs(FftSectSix).^2)+1);
PowerSec{1,7} = 10 *  log((abs(FftSectSeven).^2)+1);
PowerSec{1,8} = 10 *  log((abs(FftSectEight).^2)+1);
PowerSec{1,9} = 10 *  log((abs(FftSectNine).^2)+1);

% fft magnitude
Imagefft = fft2(image);

% Computation of power Hist
ImPower = 10 *  log((abs(Imagefft).^2)+1);
%     figure, imagesc(ImPower)
TotalHist = zeros(10,5);
%                 TotalHistTEST = cell(10,5);
PatchHist = cell(10,1);

for ii = 1 : 9
    %         ii
    Power = PowerSec{1,ii};
    edges = [0 100 150 200 300 5000];
    [HistBin, ~] = histc(Power(:), edges); % variable(:) put all values into a vector(1x(MxN))
    HistBin = HistBin/(size(Power(:),1)); % Normal
    TotalHist(ii,1:5) = HistBin(1:5,1);
    
    FftHist = PatchesHist(Power);
    PatchHist(ii,:,:) = {FftHist};
    
    clear Power FftHist
end
% Image edge histogram
edges = [0 100 150 200 300 5000];
[HistBin, ~] = histc(ImPower(:), edges); % variable(:) put all values into a vector(1x(MxN))
HistBin = HistBin/(size(ImPower(:),1)+eps); % Normal
TotalHist(10,1:5) = HistBin(1:5,1);

[FftHist] = PatchesHist(ImPower);
PatchHist(10,:,:) = {FftHist};
%--------------------------------------------------

% Creation of a .txt file in form compatible with the LibSVM
countFeat = 1;
fprintf(fidBlur,'%i ', label);
for ic =  1 : 10
    for jc = 1 : 5
        fprintf(fidBlur,'%i: %.6f ', countFeat, TotalHist(ic,jc));
        countFeat = countFeat + 1;
    end
end

for ic = 1 : 10
    patches = cell2mat(PatchHist{ic,:});
    for x = 1 : 9
        for y = 1 : 5
            fprintf(fidBlur,'%i: %.6f ',countFeat, patches(x,y));
            countFeat = countFeat + 1;
        end
    end
end
%--------------------------------------------------

clear SectOne SectTwo SectThree SectFour SectFive SectSix SectSeven SectEight SectNine  PowerSec
clear FftSectOne FftSectTwo FftSectThree FftSectFour FftSectFive FftSectSix FftSectSeven FftSectEight FftSectNine TotalHist PatchHist

%% Wavelet transform for image blur detection
% The number of the scales of the Haar transformation
NumScales = 3;
% Haar transformation
[C, S] = wavedec2(image,NumScales,'haar');
for ii = 1 : NumScales
    [horizontal, vertical, diagonal] = detcoef2('all',C,S,ii);
    % Compute the edge map in each scale
    Emap = sqrt(horizontal.^2 + vertical.^2 + diagonal.^2);
    % Wavelet & Rule of Thirds
    [countFeat] = WaveletRuleOfThirds(Emap, ii, fidBlur, countFeat);
end
%--------------------------------------------------

fprintf(fidBlur,'\n');

% End of function
end