%% SimpleMeasure : extract the appropriate features for simplicity assessment
function SimplicityMeasure(image, HSVimage, Labimage, fidSimple, label)

% Initialize countFeat value
countFeat = 1;

% Print the label of the feature vector
fprintf(fidSimple,'%i ',label);

% Detect the main subject of the image
[mainSubject] = imageSegmentation(image);
if (size(mainSubject(mainSubject==0),1)/(size(mainSubject,1)*size(mainSubject,2)) > 0.90) ||  (size(mainSubject(mainSubject==1),1)/(size(mainSubject,1)*size(mainSubject,2)) > 0.90)
    [mainSubject] = kmeansSegmentation(image, Labimage, 2);
    mainSubject(mainSubject==1) = 0;
    mainSubject(mainSubject==2) = 1;
end

%% Spatial arrangement of the main subject using rule of thirds grid
[countFeat] = ruleOfThirds( mainSubject, fidSimple, countFeat );
%--------------------------------------------------

%% Statistical analysis of the main subject and background HSV histogram distributions
% Extract H, S, V image channels
H = HSVimage(:,:,1);
S = HSVimage(:,:,2);
V = HSVimage(:,:,3);

% Cell components
objComp = cell(6,1);
objComp{1,1} = double(H(mainSubject==0));
objComp{2,1} = double(H(mainSubject==1));
objComp{3,1} = double(S(mainSubject==0));
objComp{4,1} = double(S(mainSubject==1));
objComp{5,1} = double(V(mainSubject==0));
objComp{6,1} = double(V(mainSubject==1));

for j = 1 : 2 : 6
    
    % Prepare the data sample so as to x and y contains equal number of data
    x = objComp{j,1};
    y = objComp{(j+1),1};
       
    % Statistical analysis of two distributions
    if ~(isempty(x) && isempty(y)) && ~(std(x)==0 || std(y)==0)
        mux = nanmean(x);
        muy = nanmean(y);
        stdx = nanstd(x);
        stdy = nanstd(y);
        sx1x2 = sqrt(((stdx.^2)./size(x,1))+((stdy.^2)./size(y,1)));
        
        % Kurtosis
        krtx = kurtosis(x);
        krty = kurtosis(y);
        
        % Skewness
        skewx = skewness(x);
        skewy = skewness(y);
        
        % KullbackLeibler divergence
        Dkl1 =(((mux-muy).^2)/(2*stdy.^2));
        Dkl2 = 0.5*((stdx.^2/stdy.^2)-1-log(stdx.^2/stdy.^2));
        Dkl = Dkl1 + Dkl2;
        
        if ~(size(mux(isnan(mux)),1)==size(mux,1)) &&  ~(size(muy(isnan(muy)),1)==size(muy,1))
            fprintf(fidSimple,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, mux, countFeat+1, muy, countFeat+2, stdx, countFeat+3, stdy, countFeat+4, sx1x2, countFeat+5, skewx, countFeat+6, skewy, countFeat+7, krtx, countFeat+8, krty, countFeat+9, Dkl);
            countFeat = countFeat + 10;
        else
            fprintf(fidSimple,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, 0, countFeat+1, 0, countFeat+2, 0, countFeat+3, 0, countFeat+4, 0, countFeat+5, 0, countFeat+6, 0, countFeat+7, 0, countFeat+8, 0, countFeat+9, 0);
            countFeat = countFeat + 10;
        end
        
    else
        fprintf(fidSimple,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, 0, countFeat+1, 0, countFeat+2, 0, countFeat+3, 0, countFeat+4, 0, countFeat+5, 0, countFeat+6, 0, countFeat+7, 0, countFeat+8, 0, countFeat+9, 0);
        countFeat = countFeat + 10;
    end
    
end

%--------------------------------------------------

%% Color-difference folmula CIE 1976
[CIE1] = chromeDifference(image, Labimage, mainSubject);

%% Compute the histogram of CIE1 and CIE2
% The number of bins that be computed for each color component/channel (H, S, V)
Required_Bin_Num = 5;
% fixed width of bins

xmin = 0;                               % lower bound
xmax = 250;                             % upper bound
width = (xmax-xmin)/Required_Bin_Num;   % bin width
edges = xmin:width:xmax;
edges(end) = 250.1;

% Bin contraction
[Q_CIE1, ~] = histc(CIE1(:), edges);    % variable(:) put all values into a vector(1x(MxN))
Q_CIE1(end) = [];                       % The last bin is always zero so exclude it.
Q_CIE1 = Q_CIE1/(size(CIE1,1)+eps);     % Normalization

if ~(size(CIE1(isnan(CIE1)),1)==size(CIE1,1))
    fprintf(fidSimple,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, Q_CIE1(1), countFeat+1, Q_CIE1(2), countFeat+2, Q_CIE1(3), countFeat+3, Q_CIE1(4), countFeat+4, Q_CIE1(5));
else
    fprintf(fidSimple,'%i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f %i: %0.6f ', countFeat, 0, countFeat+1, 0, countFeat+2, 0, countFeat+3, 0, countFeat+4, 0);
end
%--------------------------------------------------

% End of the vector
fprintf(fidSimple,'\n');

% End of the function
end

