%% chromeDifference :  considering two color regions of the image, 
%% the main subject and the background, we estimate a 5-bin histogram 
%% of the color-difference formula CIE 1976
%% Reference : http://www.imatest.com/docs/colorcheck_ref/
function [CIE] = chromeDifference(image, Lab, mainSubject)

% L channel
L = Lab(:,:,1);
% a channel
a = Lab(:,:,2);
% b channel
b = Lab(:,:,3);

% Compute the "ab" space
ab = double(Lab(:,:,2:3));
nrows = size(ab,1);
ncols = size(ab,2);
ab = reshape(ab,nrows*ncols,2); % ab(nrows, ncols, 2)

% If the image is in grayscale and a,b == 128 compute the R-G-B
% channels
if size(ab(ab==128),1) > (size(ab(:),1)/3)*2
    % R channel
    L = image(:,:,1);
    % G channel
    a = image(:,:,2);
    % B channel
    b = image(:,:,3);
end

objComp = cell(6,1);

% Edge based image segmentation
% L
objComp{1,1} = double(L(mainSubject==0));
objComp{2,1} = double(L(mainSubject==1));

% a
objComp{3,1} = double(a(mainSubject==0));
objComp{4,1} = double(a(mainSubject==1));

% b
objComp{5,1} = double(b(mainSubject==0));
objComp{6,1} = double(b(mainSubject==1));

for j = 1 : 2 : 6
    x = objComp{j,1};
    y = objComp{(j+1),1};
    if size(y,1) >= size(x,1)
        objComp{(j+1),1} = datasample(y,size(x,1),'Replace',false);
    elseif size(x,1) >= size(y,1)
        objComp{j,1} = datasample(x,size(y,1),'Replace',false);
    end
end

% Compare 3 main image colors
colorA = 1;
colorB = 2;

% Color-difference formula, CIE 1976
dL = abs(objComp{colorA,1}-objComp{colorB,1}); % L1-L2
da = abs(objComp{colorA+2,1}-objComp{colorB+2,1}); % a1-a2
db = abs(objComp{colorA+4,1}-objComp{colorB+4,1}); % b1-b2

CIE = sqrt(dL.^2 + da.^2 + db.^2);

% End of the function
end