%% imageSegmentation : performs image segmentation for the input image in order to detect the main Subject
function [mainSubject] = imageSegmentation(image)

imDouble = double(rgb2gray(image));
% Compute the the first order derivative of Image I in x, and in y direction
[gx,gy] = gradient(imDouble);

% Transform Cartesian coordinates to polar
[th, mag] = cart2pol(gx,gy);

meanMag = mean(mean(mag));
if meanMag > 8
    imEdges = (abs(th).*(mag>floor(meanMag)));
elseif meanMag < 8
    imEdges = (abs(th).*(mag>ceil(meanMag)));
end

% Detect the boundary of the main object
boundary = bwperim(imEdges,18);

% Remove all connected components that have fewer than p pixels
p = 1000;
mainSubject = bwareaopen(boundary,p);

% Filing the holes
numOne = size(mainSubject(mainSubject==1),1);
numZero = size(mainSubject(mainSubject==0),1);
if numOne  > numZero
    mainSubject = ~mainSubject;
end
mainSubject = imfill(mainSubject,'holes');
mainSubject = imdilate(mainSubject,ones(2, 2));

% Re-fill the holes
mainSubject = imfill(mainSubject,'holes');

% Convert the initial image to binary image
imBw = im2bw(image,0.8); %0.6 h 0.3 h 0.8

% Filling the holes
imBw = imfill(imBw,'holes');

% Detect the perimeter (boundary) of the image
imPerimetry = bwperim(imBw,8);

% Remove all components that have fewer than p pixels
p = 1000;
imPerimetry =  bwareaopen(imPerimetry,p);
imBw = imfill(imPerimetry,'holes');

% Sum the two image segments
im = mainSubject + imBw;

im(im==2) = 1;
check = 0;
if size(im(im==1),1) > (size(im(:),1)/5)*3.5
    im = mainSubject + (~imBw);
    check = 1;
end
% Dilate image boundary
im = imdilate(im,ones(2, 2));

% Re-fill the holes
im = imfill(im,'holes');
im = im2bw(im,0.7);

if check == 1
    mainSubject = ~im;
else
    mainSubject = im;
end

% End of the function
end