%% ruleOfThirds : compute the percentage of main subject pixels 
%% that appear in each of the 9 patches of the rule of thirds grid
function [countFeat] = ruleOfThirds( mainSubject, fid, countFeat )

[row, col,~] = size(mainSubject);
StX = 1;
StY = 1;
EnX = floor(col/3);
EnY = floor(row/3);

for i = 1 : 3
    for j = 1 :3
        Area = (EnX-StX)*(EnY-StY);
        % Computation of spatial distribution of middle points
        % The number of bins that be computed for each color component/channel (H, S, V)
        Required_Bin_Num = 5;
        
        % X - axis
        xmin = StX;                             % lower bound
        xmax = EnX;                             % upper bound
        width = (xmax-xmin)/Required_Bin_Num;   % bin width
        edges = xmin:width:xmax;
        edges(end) = EnX+0.1;
        edges = floor(edges);
        
        % Print the corresponding values
        objOneY = cell(4,1);
        objTwoY = cell(4,1);
        for ii = 1 : 4
            spatBin = mainSubject(StY:EnY,edges(ii):edges(ii+1));
            
            objOneY{ii} = size(spatBin(spatBin==1),1)/ Area ;
            objTwoY{ii} = size(spatBin(spatBin==0),1)/ Area;
            
        end
        
        % Y - axis
        xmin = StY;                             % lower bound
        xmax = EnY;                             % upper bound
        width = (xmax-xmin)/Required_Bin_Num;   % bin width
        edges = xmin:width:xmax;
        edges(end) = EnY+0.1;
        edges = floor(edges);
        
        % Print the corresponding values
        objOneX = cell(4,1);
        objTwoX = cell(4,1);
        for ii = 1 : 4
            spatBin = mainSubject(edges(ii):edges(ii+1),StX:EnX);

            objOneX{ii} = size(spatBin(spatBin==1),1)/ Area ;
            objTwoX{ii} = size(spatBin(spatBin==0),1)/ Area;
            
        end
        
        % Print the results
        for ii = 1 : 4
            fprintf(fid,'%i: %0.6f ', countFeat,objOneY{ii});
            countFeat = countFeat + 1;
        end
        for ii = 1 : 4
            fprintf(fid,'%i: %0.6f ', countFeat,objTwoY{ii});
            countFeat = countFeat + 1;
        end
        for ii = 1 : 4
            fprintf(fid,'%i: %0.6f ', countFeat,objOneX{ii});
            countFeat = countFeat + 1;
        end
        for ii = 1 : 4
            fprintf(fid,'%i: %0.6f ', countFeat,objTwoX{ii});
            countFeat = countFeat + 1;
        end
        
        StX = floor((col*j)/3);
        EnX = floor((col*(j+1))/3);
    end
    StX = 1;
    EnX = floor(col/3);
    StY = floor((row*i)/3);
    EnY = floor((row*(i+1))/3);
end
clear middlePoints pointSt pointX pointY

% End of the function
end
