%% removeFrame : remove the frame / Border from an input image
function [image] = removeFrame(rgbCrop)

% Convert the image from Rgb colorspace to grayscale
[inRow, inCol, nCol] = size(rgbCrop);

if nCol == 3
    grayCrop = rgb2gray(rgbCrop);
else
    grayCrop = rgbCrop;
end
frame = 1;                              % initialize the frame parameter
grayCrop =  adapthisteq(grayCrop);      % enhance the contrast of input image

while frame == 1
    
    [row, col] = size(grayCrop);
    bw = edge(grayCrop,'canny');         % Perform canny edge detection
    
    StCol1 = bw(:,1);                    % Initialize first column vector
    StRow1 = bw(1,:);                    % Initialize first row vector
     
    for i = 2 : round(row/15)            % For first "round(row/15)" rows 
        EnCol1 = bw(:,i);                % check if the color of the 
        DifCol1 = abs(StCol1-EnCol1);    % corresponding pixels remains the same
              
        StX = 1;
        if ~isempty(find(DifCol1,1)) 
            StX = i+5;                   % If the color is the same move the start
            break                        % point 5 pixels in order to crop the input image
        end
        
    end
    
    for j = 2 : round(col/15)            % For first "round(col/15)" columns 
        EnRow1 = bw(j,:);                % check if the color of the 
        DifRow1 = abs(StRow1-EnRow1);    % corresponding pixels remains the same
       
        StY = 1;
        if ~isempty(find(DifRow1,1))     % If the color is the same move the start
            StY = j+5;                   % point 5 pixels in order to crop the input image
            break
        end
    end
    
    % If there is not found a border since round(col/15) or round(row/15)
    % break
    if (StY==1) || (StX ==1)
        break;
    end
    
    % Crop the input image
    rgbCrop = rgbCrop(StY:end-StY,StX:end-StX,:);
    
    [~, ~, nCol] = size(rgbCrop);
    if nCol == 3
        grayCrop = rgb2gray(rgbCrop);
    else
        grayCrop = rgbCrop;
    end
    
    bw = edge(grayCrop,'canny');        % Perform canny edge detection
    tempCol = bw(:,1:2);
    tempRow = bw(1:2,:);
    if size(unique(tempCol),1) ~= 1
        frame = 0 ;
    end
    if  size(unique(tempRow),1) ~= 1
        frame = 0 ;
    end
    
    tempCol = bw(:,end-2:end);
    tempRow = bw(end-2:end,:);
    if size(unique(tempCol),1) ~= 1
        frame = 0 ;
    end
    if  size(unique(tempRow),1) ~= 1
        frame = 0 ;
    end
    
end

%% Check if there is an image frame near to the main object ( the process is the same as the aforementioned)
[row, col] = size(grayCrop);
bw = edge(grayCrop,'canny');


StCol1 = bw(:,1);
StRow1 = bw(1,:);


for i = 2 : round(row/8)
    EnCol1 = bw(:,i);
    DifCol1 = abs(StCol1-EnCol1);
    
    StX = 1;
    if ~isempty(find(DifCol1,1))
        StX = i+4;
        break;
    end
    
end

for j = 2 : round(col/8)
    EnRow1 = bw(j,:);
    DifRow1 = abs(StRow1-EnRow1);
    
    StY = 1;
    if ~isempty(find(DifRow1,1))
        StY = j+4;
        break;
    end
end

% If there is not found a border since round(col/12) or round(row/12)
% break
if StY > 4
    borderCol =  EnCol1((StY-4):end-(StY-4));
else
    borderCol =  EnCol1((StY):end-(StY));
end

if StX > 4
    borderRow =  EnRow1((StX-4):end-(StX-4));
else
    borderRow =  EnRow1((StX):end-(StX));
end

borderCountCol = size(borderCol(borderCol==1),1);
borderCountRow = size(borderRow(borderRow==1),2);
isBorderCol = borderCountCol / size(borderCol,1);
isBorderRow = borderCountRow / size(borderRow,2);
if isBorderCol > 0.8 && isBorderRow > 0.8
    % Crop the image
    rgbCrop = rgbCrop(StY:end-StY,StX:end-StX,:);
end

% Final image
if inRow > 480 && inCol > 480
    rgbCrop = rgbCrop(StY+10:end-StY-10,StX+10:end-StX-10,:);
end
image = rgbCrop;

% End of the function
end
